@@ -30,16 +30,16 @@ class SinkInput : public Stream
 {
     Q_OBJECT
 public:
-    SinkInput(QObject *parent);
+    explicit SinkInput(QObject *parent);
 
     void update(const pa_sink_input_info *info);
 
     void setSinkIndex(quint32 sinkIndex);
 
-    void setVolume(qint64 volume) Q_DECL_OVERRIDE;
-    void setMuted(bool muted) Q_DECL_OVERRIDE;
-    void setChannelVolume(int channel, qint64 volume) Q_DECL_OVERRIDE;
-    void setDeviceIndex(quint32 deviceIndex) Q_DECL_OVERRIDE;
+    void setVolume(qint64 volume) override;
+    void setMuted(bool muted) override;
+    void setChannelVolume(int channel, qint64 volume) override;
+    void setDeviceIndex(quint32 deviceIndex) override;
 };
 
 } // QPulseAudio
